# Radicale IMAP authentication plugin

IMAP authentication plugin for [Radicale](http://radicale.org/).
This is a simplification fork of [https://github.com/Unrud/RadicaleIMAP](RadicaleIMAP).

## Installation

    python3 -m pip install radicale-imap

## Configuration

    [auth]
    type = radicale_imap
    imap_host = address:port
    imap_secure = True

## License

[GPL-3.0](LICENSE)
